<?php
/**********************************************************************************
* Subs-ProfileVisitors.php                                                        *
***********************************************************************************
* ProfileVisitors                                                                 *
* =============================================================================== *
* Software Version:           ProfileVisitors 4.1                                 *
* Software by:                Blue Dream (http://www.simpleportal.net)            *
* Copyright 2006-2008 by:     Blue Dream (http://www.simpleportal.net)            *
* Support, News, Updates at:  http://www.simplemachines.org                       *
***********************************************************************************
* This program is free software; you may redistribute it and/or modify it under   *
* the terms of the provided license as published by Simple Machines LLC.          *
*                                                                                 *
* This program is distributed in the hope that it is and will be useful, but      *
* WITHOUT ANY WARRANTIES; without even any implied warranty of MERCHANTABILITY    *
* or FITNESS FOR A PARTICULAR PURPOSE.                                            *
*                                                                                 *
* See the "license.txt" file for details of the Simple Machines license.          *
* The latest version can always be found at http://www.simplemachines.org.        *
**********************************************************************************/

if (!defined('SMF'))
	die('Hacking attempt...');

/*	This file handles everything related to ProfileVisitors.

	void pv_log_visitor(int memID)
		// !!!

	void pv_log_count(int memID)
		// !!!

	void pv_delete(int memID)
		// !!!

	array pv_get_visitor(int memID, int limit = null)
		// !!!

	array pv_allowedTo(string permission, int memID)
		// !!!

*/

function pv_log_visitor($memID)
{
	global $smcFunc, $context, $user_info, $options;

	pv_log_count($memID);

	if ($context['user']['is_guest'] || $context['user']['is_owner'] || isset($_GET['pv']))
		return;
	elseif (allowedTo('pv_avoid_log') && !empty($options['pv_avoid_log']))
		return;

	$smcFunc['db_query']('', '
		UPDATE {db_prefix}log_profile_visitors
		SET views = views + 1, time = {int:time}
		WHERE id_member = {int:member}
			AND id_profile = {int:profile}
		LIMIT 1',
		array(
			'member' => $user_info['id'],
			'profile' => $memID,
			'time' => time(),
		)
	);

	if ($smcFunc['db_affected_rows']() == 0)
	{
		$smcFunc['db_insert']('ignore',
			'{db_prefix}log_profile_visitors',
			array('id_member' => 'int', 'id_profile' => 'int', 'views' => 'int', 'time' => 'int'),
			array($user_info['id'], $memID, 1, time()),
			array('id_member', 'id_profile')
		);
	}
}

function pv_log_count($memID)
{
	global $smcFunc, $context;

	if ($context['user']['is_owner'])
		return;

	$smcFunc['db_query']('', '
		UPDATE {db_prefix}themes
		SET value = value + 1
		WHERE id_member = {int:profile}
			AND variable = {string:variable}
		LIMIT 1',
		array(
			'profile' => $memID,
			'variable' => 'pv_count',
		)
	);

	if ($smcFunc['db_affected_rows']() == 0)
	{
		$smcFunc['db_insert']('replace',
			'{db_prefix}themes',
			array('id_theme' => 'int', 'variable' => 'string-255', 'value' => 'string-65534', 'id_member' => 'int'),
			array(1, 'pv_count', 1, $memID),
			array('id_theme', 'variable', 'id_member')
		);
	}
}

function pv_delete($memID)
{
	global $smcFunc, $context, $user_info;

	checkSession('get');

	if ($context['user']['is_owner'] && !allowedTo('pv_remove_own'))
		isAllowedTo('pv_remove_any_any');
	elseif ($user_info['id'] == $member && !allowedTo('pv_remove_any_own'))
		isAllowedTo('pv_remove_any_any');

	$member = !empty($_REQUEST['member']) ? (int) $_REQUEST['member'] : 0;

	if (empty($member))
		fatal_lang_error('pv_no_member', false);

	$smcFunc['db_query']('', '
		DELETE FROM {db_prefix}log_profile_visitors
		WHERE id_member = {int:member}
			AND id_profile = {int:profile}
		LIMIT 1',
		array(
			'member' => $member,
			'profile' => $memID,
		)
	);

	redirectexit('action=profile;u=' . $memID . ';pv');
}

function pv_get_visitor($memID, $limit = 10)
{
	global $smcFunc, $user_info, $scripturl, $modSettings, $txt;

	if ($modSettings['avatar_action_too_large'] == 'option_html_resize' || $modSettings['avatar_action_too_large'] == 'option_js_resize')
	{
		$avatar_width = !empty($modSettings['avatar_max_width_external']) ? ' width="' . $modSettings['avatar_max_width_external'] . '"' : '';
		$avatar_height = !empty($modSettings['avatar_max_height_external']) ? ' height="' . $modSettings['avatar_max_height_external'] . '"' : '';
	}
	else
	{
		$avatar_width = '';
		$avatar_height = '';
	}

	$request = $smcFunc['db_query']('', '
		SELECT
			mem.id_member, mem.real_name, mem.avatar, IFNULL(a.id_attach, 0) AS id_attach,
			a.filename, a.attachment_type, lpv.views, lpv.time
		FROM {db_prefix}log_profile_visitors AS lpv
			LEFT JOIN {db_prefix}members AS mem ON (mem.id_member = lpv.id_member)
			LEFT JOIN {db_prefix}attachments AS a ON (a.id_member = lpv.id_member)
		WHERE lpv.id_profile = {int:profile}
		ORDER BY lpv.time DESC
		LIMIT {int:limit}',
		array(
			'profile' => $memID,
			'limit' => (int) $limit,
		)
	);
	$return = array();
	while ($row = $smcFunc['db_fetch_assoc']($request))
	{
		$nowtime = forum_time();

		$then = @getdate($row['time']);
		$now = @getdate(forum_time());

		if ($then['yday'] == $now['yday'] && $then['year'] == $now['year'])
			$time_format = '%H:%M:%S';
		else
			$time_format = '%d/%m/%y';

		$row['can_remove'] = false;

		if ($user_info['id'] == $memID && allowedTo('pv_remove_own'))
			$row['can_remove'] = true;
		elseif (allowedTo('pv_remove_any_any') || ($user_info['id'] == $row['id_member'] && allowedTo('pv_remove_any_own')))
			$row['can_remove'] = true;

		$return[] = array(
			'id' => $row['id_member'],
			'name' => $row['real_name'],
			'href' => $scripturl . '?action=profile;u=' . $row['id_member'],
			'link' => '<a href="' . $scripturl . '?action=profile;u=' . $row['id_member'] . '" title="' . $txt['profile_of'] . ' ' . $row['real_name'] . '">' . $row['real_name'] . '</a>',
			'avatar' => array(
				'name' => $row['avatar'],
				'image' => $row['avatar'] == '' ? ($row['id_attach'] > 0 ? '<img src="' . (empty($row['attachment_type']) ? $scripturl . '?action=dlattach;attach=' . $row['id_attach'] . ';type=avatar' : $modSettings['custom_avatar_url'] . '/' . $row['filename']) . '" alt="" class="avatar" border="0" />' : '') : (stristr($row['avatar'], 'http://') ? '<img src="' . $row['avatar'] . '"' . $avatar_width . $avatar_height . ' alt="" class="avatar" border="0" />' : '<img src="' . $modSettings['avatar_url'] . '/' . htmlspecialchars($row['avatar']) . '" alt="" class="avatar" border="0" />'),
				'href' => $row['avatar'] == '' ? ($row['id_attach'] > 0 ? (empty($row['attachment_type']) ? $scripturl . '?action=dlattach;attach=' . $row['id_attach'] . ';type=avatar' : $modSettings['custom_avatar_url'] . '/' . $row['filename']) : '') : (stristr($row['avatar'], 'http://') ? $row['avatar'] : $modSettings['avatar_url'] . '/' . $row['avatar']),
				'url' => $row['avatar'] == '' ? '' : (stristr($row['avatar'], 'http://') ? $row['avatar'] : $modSettings['avatar_url'] . '/' . $row['avatar'])
			),
			'views' => $row['views'],
			'time' => timeformat($row['time'], $time_format),
			'can_remove' => $row['can_remove'],
		);
	}
	$smcFunc['db_free_result']($request);

	return $return;
}

function pv_allowedTo($permission, $member)
{
	global $smcFunc;

	if (empty($permission))
		return true;

	if (empty($member))
		return false;

	$request = $smcFunc['db_query']('', '
		SELECT id_group, id_post_group, additional_groups
		FROM {db_prefix}members
		WHERE id_member = {int:id_member}
		LIMIT 1',
		array(
			'id_member' => (int) $member,
		)
	);
	list ($primary, $post, $additional) = $smcFunc['db_fetch_row']($request);
	$smcFunc['db_free_result']($request);

	$groups = array($primary, $post);

	if (!empty($additional))
		$groups += explode(',', $additional);

	if (in_array(1, $groups))
		return true;

	$request = $smcFunc['db_query']('', '
		SELECT add_deny
		FROM {db_prefix}permissions
		WHERE id_group IN ({array_int:member_groups})
			AND permission = {string:permission}',
		array(
			'member_groups' => $groups,
			'permission' => $permission,
		)
	);
	list ($result) = $smcFunc['db_fetch_row']($request);
	$smcFunc['db_free_result']($request);

	return empty($result) ? false : true;
}

?>